Revert "default GetLuciAuth to latest SHA1 version"

This reverts commit 84a47a383d4d10d5dba6af48b01d83f8ac8393a2.

Reason for revert: crbug.com/874164

It appears that this CL is not correct for older branches.

Original change's description:
> default GetLuciAuth to latest SHA1 version
> 
> BUG=chromium:871831
> TEST=local unit test
> 
> default to latest SHA1 instead of latest to
> fix old branches.
> 
> Change-Id: Ib14ec566181908a054c14f2d84b48ff5af0e76e6
> (cherry picked from commit dd861a00fcd4134f9eecddf9607dd2af067113aa)
> Reviewed-on: https://chromium-review.googlesource.com/1168171
> Reviewed-by: Gregory Meinke <gmeinke@chromium.org>
> Tested-by: Mike Frysinger <vapier@chromium.org>
> Commit-Queue: Gregory Meinke <gmeinke@chromium.org>

BUG=chromium:871831,chromium:874164

Change-Id: Id69980d54bf11e1e36aec43e9206d20056d1729d
Reviewed-on: https://chromium-review.googlesource.com/1177254
Reviewed-by: Mike Frysinger <vapier@chromium.org>
Commit-Queue: Mike Frysinger <vapier@chromium.org>
Tested-by: Mike Frysinger <vapier@chromium.org>
diff --git a/lib/auth.py b/lib/auth.py
index 09af99a..bddb9f6 100644
--- a/lib/auth.py
+++ b/lib/auth.py
@@ -27,18 +27,14 @@
   """Error accessing the token."""
 
 
-# crbug:871831 default to last sha1 version.
-def GetAuthUtil(
-    instance_id='git_revision:fd059ace316e4dbcaa5afdcec9ed4a855c4f3c65'):
+def GetAuthUtil(instance_id='latest'):
   """Returns a path to the authutil binary.
 
   This will download and install the authutil package if it is not already
   deployed.
 
   Args:
-    instance_id: The instance-id of the package to install. Defaults to
-    'git_revision:fd059ace316e4dbcaa5afdcec9ed4a855c4f3c65' which is the last
-    SHA1 version.
+    instance_id: The instance-id of the package to install. Defaults to 'latest'
 
   Returns:
     the path to the authutil binary.